@@ -102,6 +102,7 @@ class Env:
         exit = False
         self.render()
         self.step([0, 0, 0])
+        score = 0
         while not exit :
             key = get()
             if key == "up":
@@ -114,7 +115,9 @@ class Env:
                 a = [0, 0, 20]
             else :
                 exit = True
-            self.step(a)
+            _, reward, _, info = self.step(a)
+            score += reward
+            print(score, info)
             self.render()
 
 
