@@ -1,6 +1,7 @@
 from pyrace.setting import Setting
 from pyrace.model.modelregistery import ModelRegistery
 from pyrace.model.car import Car
+import numpy
 
 class Model:
     def __init__(self, model_name, vue):
@@ -11,11 +12,12 @@ class Model:
         self.car = Car(self.vue.metadata, self.metadata)
         
         self.progress = 0
+        self.idx_proj = 0
         
         self.state = self.car.get_state(self.vue)
         self.reward = 0
         self.done = False
-        self.info = {}
+        self.info = {'status' : 'racing'}
         self.history = [(self.state, self.reward, self.done, self.info)]
 
 
@@ -25,19 +27,29 @@ class Model:
 
             self.state = self.car.get_state(self.vue)
 
-            progress, circuit_lenght = self.vue.get_progress(self.car.position)
+            progress, idx_proj = self.vue.get_progress(self.car.position)
             
-            if progress - self.progress > 1000 : # detect if the car went back after departure
-                progress = progress - circuit_lenght
 
-            self.reward = progress - self.progress
-            self.progress = progress
+            if (self.idx_proj==0) and (idx_proj==len(self.vue.schema)-2):
+                self.done = True
+                self.info['status'] = 'false departure'
 
             if not self.vue.is_road(self.car.position):
                 self.done = True
+                self.info['status'] = 'crached'
 
-            self.info = {}
+            if self.idx_proj > len(self.vue.schema)-2:
+                self.done = True
+                self.info['status'] = 'completed'
 
+            if numpy.abs(progress - self.progress) < 200 :  # sometime the projection is not right.........
+                self.reward = progress - self.progress
+                self.progress = progress
+            else :
+                self.progress += self.reward
+
+            self.idx_proj = idx_proj
+            
             self.history.append((self.state, self.reward, self.done, self.info))
             return self.state, self.reward, self.done, self.info
 
