@@ -1,4 +1,5 @@
 import numpy
+from pyrace.setting import Setting
 
 class Camera:
         def __init__(self, observer_metadata):
@@ -22,5 +23,12 @@ class Camera:
                     value = 240
                 except :
                     raise
+                
+                if self.metadata['values_type']=='binary':
+                    if numpy.abs(value - Setting.ROAD_COLOR) < 20 :
+                        value = 1
+                    else :
+                        value = 0
+
                 values.append(value)
             return values
\ No newline at end of file
