@@ -41,7 +41,7 @@ class Vue:
         self.schema_numpy = numpy.array(self.schema)
         self.cum_dist_schema = numpy.cumsum([edist(self.schema_numpy[i], self.schema_numpy[i+1]) for i in range(len(self.schema)-1)])
 
-
+        self.projection = (490, 520) # for plot purpose -> remove
 
     def is_road(self, position):
         try :
@@ -73,6 +73,10 @@ class Vue:
             cursor_positions = [(x[0] + Setting.MARKER_SIZE//2 - car_img_size[0]//2, x[1] + Setting.MARKER_SIZE//2 - car_img_size[1]//2) for x in car.observer.cursor_positions]
             cursor_images = [self.marker_img.rotate(angle=theta, resample=Image.NEAREST, expand=True) for theta in car.observer.thetas]
 
+        for point_ in self.metadata['schema'] :
+            render_img.paste(self.marker_img, point_, self.marker_img)
+
+        render_img.paste(self.marker_img, tuple(self.projection), self.marker_img)
 
         # elif car.observation_space.description['observer_type'] == 'GPS' :
         #     # coming soon
@@ -93,6 +97,8 @@ class Vue:
         idx_proj = numpy.argmin(distproj)
         projection = projections[idx_proj]
 
+        self.projection = projection
+
 
         if idx_proj == 0 :
             dist_segment = 0
@@ -100,13 +106,12 @@ class Vue:
             dist_segment = self.cum_dist_schema[idx_proj - 1]
 
 
-
         segment = self.schema_numpy[idx_proj]
 
         dist_last = edist(segment, projection)
         output_dist = dist_last + dist_segment
 
-        return output_dist, self.cum_dist_schema[-1]
+        return output_dist, idx_proj
 
 
 
